Klinisk sekvensering av cancerprover - Kvalitetsrapport

# Kvalitetsrapport

# Klinisk sekvensering av cancerprover

### rapportdatum: 2021-02-02 00:40

# Provinformation

ProvID
  FS000XXX
Analyspanel
  gmck-solid
Analyskod
  PAN123456
Analysdatum
  2021-01-25 08:53
Bioinformatiskanalys:
  BALSAMIC version 6.0.4

# Sammanfattning

Prov-id | Provtyp | Mediansekvensdjup [x] | Fold 80 base penalty | Fragmentlängd, medel [baspar]
--- | --- | --- | --- | ---
normal | KS656 | 597.0 | 1.47 | 125.82
tumor | KS454 | 805.0 | 1.57 | 131.28

# Täckningsgrad för vald analyspanel

Prov-id | Provtyp | Täckningsgrad [50X] | Täckningsgrad [100X] | Täckningsgrad [200X] | Täckningsgrad [500X] | Täckningsgrad [1000X]
--- | --- | --- | --- | --- | --- | ---
normal | KS656 | 99.84 % | 99.5 % | 97.72 % | 67.94 % | 8.52 %
tumor | KS454 | 99.86 % | 99.72 % | 98.72 % | 87.46 % | 30.44 %

# Förklaringar

Värdena presenterade för Mediansekvensdjup och Täckningsgrad är efter borttagning av duplikata läsningar.

Mediansekvensdjup: Median av sekvenseringsdjup över alla baser inkluderade i analyspanelen.

Fold 80 base penalty: Jämnhet av täckningsgraden över alla gener i analyspanlen. Ett värde mellan 1.0-1.8 visar god jämnhet.

Fragmentlängd, medel: Medelstorlek av provbiblioteken som laddats på sekvenseringsinstrument. <200bp kan tyda på degraderade provmaterial (t.ex. FFPE), innan biblioteksberedning.

Täckningsgrad: Andel baser som är sekvenserade med ett djup över en specificerad gräns, t.ex. 100X.